@@ -1,32 +1,41 @@
-package Ubic::Lockf;
-{
-  $Ubic::Lockf::VERSION = '1.57_01';
+package Ubic::Lockf::Alarm;
+
+# we can't use alarm from Time::HiRes, it don't return current alarm value on perl 5.8.8
+
+sub new ($$) {
+    my ($class, $timeout) = @_;
+    bless { 'alarm' => alarm($timeout), 'time' => time };
 }
 
+sub DESTROY ($) {
+    my $self = shift;
+    my $alarm;
+    if ($self->{alarm}) {
+        $alarm = $self->{alarm} + $self->{time} - time;
+        $alarm = 1 if $alarm <= 0;
+    } else {
+        $alarm = 0;
+    }
+    alarm($alarm);
+}
+
+package Ubic::Lockf;
 use strict;
-use warnings;
-
-# ABSTRACT: file locker with an automatic out-of-scope unlocking mechanism
-
-
 use Fcntl qw(:flock);
 
 use Params::Validate;
 use POSIX qw(:errno_h);
 use Carp;
 
-use Ubic::Lockf::Alarm;
-
-use parent qw(Exporter);
+use base qw(Exporter);
 
 our @EXPORT = qw(lockf);
 
 
 sub DESTROY ($) {
     my ($self) = @_;
-    local $@;
     my $fh = $self->{_fh};
-    return unless defined $fh; # already released or dissolved
+    return unless defined $fh; # already released
     flock $fh, LOCK_UN;
     delete $self->{_fh}; # closes the file if opened by us
 }
@@ -107,31 +116,16 @@ sub _lockf ($$;$) {
 
 sub name($)
 {
-    my $self = shift;
+    my $self = shift();
     return $self->{_fname};
 }
 
-sub dissolve {
-    my $self = shift;
-    undef $self->{_fh};
-}
-
 1;
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 Ubic::Lockf - file locker with an automatic out-of-scope unlocking mechanism
 
-=head1 VERSION
-
-version 1.57_01
-
 =head1 SYNOPSIS
 
     use Ubic::Lockf;
@@ -141,9 +135,11 @@ version 1.57_01
 
 =head1 DESCRIPTION
 
-C<lockf> is a perlfunc C<flock> wrapper. The lock is autotamically released as soon as the associated object is
+C<lockf> is a perlfunc C<flock> wrapper. The lock is autotamically released as soon as the assotiated object is
 no longer referenced.
 
+C<lockf_multi> makes non-blocking C<lockf> calls for multiple files and throws and exception if all are locked.
+
 =head1 METHODS
 
 =over
@@ -165,8 +161,8 @@ OFF by default. Tells to achieve a shared lock. If not set, an exclusive lock is
 =item I<blocking>
 
 ON by default. If unset, a non-blocking mode of flock is used. If this flock fails because the lock is already held by some other process,
-C<undef> is returned. If the failure reason is somewhat different, permissions problems or the
-absence of a target file directory for example, an exception is raised.
+C<undef> is returned. If the failure reason is somewhat different, permissions problems or the 
+absence of a target file directory for example, an exception is raisen.
 
 =item I<timeout>
 
@@ -182,23 +178,6 @@ Undef by default. If set, a chmod with the specified mode is performed on a newl
 
 Gives the name of the file, as it was when the lock was taken.
 
-=item B<dissolve()>
-
-Destroy lock object without unlocking.
-
-This is useful in forking code, if you have one lock object in several processes and want to close locked fh in one process without unlocking in the other.
-
 =back
 
-=head1 AUTHOR
-
-Vyacheslav Matyukhin <mmcleric@yandex-team.ru>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Yandex LLC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
